@@ -1,7 +1,6 @@
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, Optional, Union
 
 import cryptography
-import pyhpke
 from cryptography.hazmat.primitives import hashes
 from cryptography.hazmat.primitives.asymmetric import ec
 from cryptography.hazmat.primitives.asymmetric.ec import (
@@ -19,16 +18,12 @@ from ..const import (
     COSE_ALGORITHMS_CKDM_KEY_AGREEMENT_ES,
     COSE_ALGORITHMS_HPKE,
     COSE_ALGORITHMS_SIG_EC2,
-    COSE_KEY_LEN,
     COSE_KEY_OPERATION_VALUES,
     COSE_KEY_TYPES,
 )
-from ..cose_key_interface import COSEKeyInterface
-from ..exceptions import DecodeError, EncodeError, VerifyError
-from ..hpke_cipher_suite import HPKECipherSuite
-from ..utils import i2osp, os2ip, to_cis
+from ..exceptions import EncodeError, VerifyError
+from ..utils import i2osp, os2ip
 from .asymmetric import AsymmetricKey
-from .symmetric import AESCCMKey, AESGCMKey, ChaCha20Key, HMACKey
 
 
 class EC2Key(AsymmetricKey):
@@ -275,34 +270,7 @@ class EC2Key(AsymmetricKey):
         except ValueError as err:
             raise VerifyError("Invalid signature.") from err
 
-    def seal(self, suite: HPKECipherSuite, msg: bytes, aad: bytes = b"") -> Tuple[bytes, bytes]:
-        # if self._alg != -1:
-        #     raise ValueError("alg should be HPKE(-1).");
-        if self._private_key is not None:
-            raise ValueError("Private key cannot be used for HPKE encryption.")
-
-        ctx = self._create_hpke_context(suite)
-        enc, sender = ctx.setup_send(self._public_key, b"")  # TODO: Add support for info
-        return enc, sender.aead.seal(aad, msg)
-
-    def open(self, suite: HPKECipherSuite, enc: bytes, msg: bytes, aad: bytes = b"") -> bytes:
-        # if self._alg != -1:
-        #     raise ValueError("alg should be HPKE(-1).");
-        if self._private_key is None:
-            raise ValueError("Public key cannot be used for HPKE decryption.")
-        ctx = self._create_hpke_context(suite)
-        try:
-            recipient = ctx.setup_recv(enc, self._private_key, b"")  # TODO: Add support for info
-            return recipient.aead.open(aad, msg)
-        except Exception as err:
-            raise DecodeError("Failed to decrypt.") from err
-
-    def derive_key(
-        self,
-        context: Union[List[Any], Dict[str, Any]],
-        material: bytes = b"",
-        public_key: Optional[COSEKeyInterface] = None,
-    ) -> COSEKeyInterface:
+    def derive_bytes(self, length: int, material: bytes = b"", info: bytes = b"", public_key: Optional[Any] = None) -> bytes:
 
         if self._public_key:
             raise ValueError("Public key cannot be used for key derivation.")
@@ -313,35 +281,19 @@ class EC2Key(AsymmetricKey):
         if self._alg not in COSE_ALGORITHMS_CKDM_KEY_AGREEMENT.values():
             raise ValueError(f"Invalid alg for key derivation: {self._alg}.")
 
-        # Validate context information.
-        if isinstance(context, dict):
-            context = to_cis(context, self._alg)
-        else:
-            self._validate_context(context)
-
-        # Derive key.
-        self._key = self._private_key if self._private_key else ec.generate_private_key(self._crv_obj)
-        shared_key = self._key.exchange(ec.ECDH(), public_key.key)
-        hkdf = HKDF(
-            algorithm=self._hash_alg(),
-            length=COSE_KEY_LEN[context[0]] // 8,
-            salt=None,
-            info=self._dumps(context),
-        )
-        # return COSEKey.from_symmetric_key(hkdf.derive(shared_key), alg=context[0])
-        cose_key = {
-            1: 4,
-            3: context[0],
-            -1: hkdf.derive(shared_key),
-        }
-        if cose_key[3] in [1, 2, 3]:
-            return AESGCMKey(cose_key)
-        if cose_key[3] in [4, 5, 6, 7]:
-            return HMACKey(cose_key)
-        if cose_key[3] in [10, 11, 12, 13, 30, 31, 32, 33]:
-            return AESCCMKey(cose_key)
-        # cose_key[3] == 24:
-        return ChaCha20Key(cose_key)
+        # Derive bytes.
+        try:
+            self._key = self._private_key if self._private_key else ec.generate_private_key(self._crv_obj)
+            shared_key = self._key.exchange(ec.ECDH(), public_key.key)
+            hkdf = HKDF(
+                algorithm=self._hash_alg(),
+                length=length,
+                salt=None,
+                info=info,
+            )
+            return hkdf.derive(shared_key)
+        except Exception as err:
+            raise EncodeError("Failed to derive bytes.") from err
 
     def _der_to_os(self, key_size: int, sig: bytes) -> bytes:
         num_bytes = (key_size + 7) // 8
@@ -355,26 +307,3 @@ class EC2Key(AsymmetricKey):
         r = os2ip(sig[:num_bytes])
         s = os2ip(sig[num_bytes:])
         return encode_dss_signature(r, s)
-
-    def _create_hpke_context(self, suite: HPKECipherSuite) -> Any:
-        if self._crv == 1:
-            if suite.kem != 0x0010:
-                raise ValueError("KEM id should be 0x0010.")
-            if suite.kdf == 0x0001 and suite.aead == 0x0001:
-                return pyhpke.Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA256__AES_128_GCM
-            if suite.kdf == 0x0001 and suite.aead == 0x0003:
-                return pyhpke.Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA256__ChaCha20Poly1305
-            if suite.kdf == 0x0003 and suite.aead == 0x0001:
-                return pyhpke.Suite__DHKEM_P256_HKDF_SHA256__HKDF_SHA512__AES_128_GCM
-            raise ValueError("Unsupported kdf/aead combination.")
-        elif self._crv == 2:
-            if suite.kem != 0x0011:
-                raise ValueError("KEM id should be 0x0011.")
-            raise ValueError("Unsupported kdf/aead combination.")
-        elif self._crv == 3:
-            if suite.kem != 0x0012:
-                raise ValueError("KEM id should be 0x0012.")
-            if suite.kdf == 0x0001 and suite.aead == 0x0001:
-                return pyhpke.Suite__DHKEM_P521_HKDF_SHA512__HKDF_SHA512__AES_256_GCM
-            raise ValueError("Unsupported kdf/aead combination.")
-        raise ValueError("Invalid crv for HPKE.")
