@@ -45,22 +45,40 @@ class TestCOSESample:
         mac_key = COSEKey.generate_symmetric_key(alg="HS512", kid="01")
 
         # The sender side:
-        r = Recipient.new(unprotected={"alg": "direct", "kid": mac_key.kid})
+        r = Recipient.new(unprotected={"alg": "direct"})
 
-        sender = COSE.new()
-        encoded = sender.encode_and_mac(b"Hello world!", mac_key, recipients=[r])
+        sender = COSE.new(alg_auto_inclusion=True, kid_auto_inclusion=True)
+        encoded = sender.encode_and_mac(
+            b"Hello world!",
+            mac_key,
+            # protected={"alg": "HS512"},
+            # unprotected={"kid": mac_key.kid},
+            recipients=[r],
+        )
 
         # The recipient side:
         recipient = COSE.new()
         assert b"Hello world!" == recipient.decode(encoded, mac_key)
 
         # variation
-        r2 = Recipient.new(unprotected={"alg": "direct", "kid": mac_key.kid})
-        encoded2 = sender.encode_and_mac(b"Hello world!", mac_key, recipients=[r2])
+        r2 = Recipient.new(unprotected={"alg": "direct"})
+        encoded2 = sender.encode_and_mac(
+            b"Hello world!",
+            mac_key,
+            protected={"alg": "HS512"},
+            unprotected={"kid": mac_key.kid},
+            recipients=[r2],
+        )
         assert b"Hello world!" == recipient.decode(encoded2, mac_key)
 
-        r3 = Recipient.new(unprotected={1: -6, 4: mac_key.kid})
-        encoded3 = sender.encode_and_mac(b"Hello world!", mac_key, recipients=[r3])
+        r3 = Recipient.new(unprotected={1: -6})
+        encoded3 = sender.encode_and_mac(
+            b"Hello world!",
+            mac_key,
+            protected={1: 7},
+            unprotected={4: mac_key.kid},
+            recipients=[r3],
+        )
         assert b"Hello world!" == recipient.decode(encoded3, mac_key)
 
         assert encoded == encoded2 == encoded3
@@ -329,13 +347,14 @@ class TestCOSESample:
 
         # The sender side:
         nonce = enc_key.generate_nonce()
-        r = Recipient.new(unprotected={"alg": "direct", "kid": enc_key.kid})
+        r = Recipient.new(unprotected={"alg": "direct"})
 
         sender = COSE.new()
         encoded = sender.encode_and_encrypt(
             b"Hello world!",
             enc_key,
-            unprotected={5: nonce},
+            protected={"alg": "ChaCha20/Poly1305"},
+            unprotected={"kid": enc_key.kid, "iv": nonce},
             recipients=[r],
         )
 
@@ -344,11 +363,12 @@ class TestCOSESample:
         assert b"Hello world!" == recipient.decode(encoded, enc_key)
 
         # variation
-        r = Recipient.new(unprotected={1: -6, 4: enc_key.kid})
+        r = Recipient.new(unprotected={1: -6})
         encoded2 = sender.encode_and_encrypt(
             b"Hello world!",
             enc_key,
-            unprotected={5: nonce},
+            protected={1: 24},  # ChaCha20/Poly1305
+            unprotected={4: enc_key.kid, 5: nonce},
             recipients=[r],
         )
         assert b"Hello world!" == recipient.decode(encoded2, enc_key)
