@@ -17,13 +17,6 @@ class TestHPKE:
         assert isinstance(ctx, HPKE)
         assert ctx.alg == -1
 
-    def test_recipient_algs_hpke_apply_without_recipient_key(self):
-        ctx = HPKE({1: -1}, {-4: {1: 0x0010, 2: 0x0001, 3: 0x0001}})
-        with pytest.raises(ValueError) as err:
-            ctx.apply()
-            pytest.fail("apply should fail.")
-        assert "recipient_key should be set." in str(err.value)
-
     def test_recipient_algs_hpke_without_alg(self):
         with pytest.raises(ValueError) as err:
             HPKE({1: 1}, {-4: {1: 0x0010, 2: 0x0001, 3: 0x0001}})
@@ -51,15 +44,15 @@ class TestHPKE:
             ),
             (
                 {-4: {1: 0xFFFF, 2: 0x0001, 3: 0x0001}},
-                "Unsupported or unknown KEM id: 65535.",
+                "65535 is not a valid KEMId",
             ),
             (
                 {-4: {1: 0x0010, 2: 0xFFFF, 3: 0x0001}},
-                "Unsupported or unknown KDF id: 65535.",
+                "65535 is not a valid KDFId",
             ),
             (
-                {-4: {1: 0x0010, 2: 0x0001, 3: 0xFFFF}},
-                "Unsupported or unknown AEAD id: 65535.",
+                {-4: {1: 0x0010, 2: 0x0001, 3: 0xFFFE}},
+                "65534 is not a valid AEADId",
             ),
         ],
     )
